# UT-LVCE: Perturbations and Causality in Gaussian Latent Variable Models

This repository contains a Python implementation of the UT-LVCE algorithms from the 2022 [paper](https://arxiv.org/abs/2101.06950) "Perturbations and Causality in Gaussian Latent Variable Models", by A. Taeb, JL. Gamella, C. Heinze-Deml and P. Bühlmann.

It is also available as the python package `utlvce`. You can find the full documentation at https://utlvce.readthedocs.io/en/latest/.

The code to reproduce the experiments and figures in the paper can be found in a separate [repository](https://github.com/juangamella/ut-lvce-paper).

### Installation
You can clone this repo or install the package using pip:
```
pip install utlvce
```

### Documentation

You can find the docs at https://utlvce.readthedocs.io/en/latest/.


### Versioning

The pacakge is still at its infancy and its API may change in the future. Non backward-compatible changes to the API are reflected by a change to the minor or major version number, e.g.

> code written using utlvce==0.1.2 will run with utlvce==0.1.3, but may not run with utlvce==0.2.0.

### Feedback

Feedback is most welcome! You can add an issue  or send an [email](mailto:juan.gamella@stat.math.ethz.ch>).
